@@ -1,10 +1,9 @@
-import redis
-
 from ._basefakesocket import BaseFakeSocket
 from .commands_mixins.bitmap_mixin import BitmapCommandsMixin
 from .commands_mixins.connection_mixin import ConnectionCommandsMixin
 from .commands_mixins.generic_mixin import GenericCommandsMixin
 from .commands_mixins.hash_mixin import HashCommandsMixin
+from fakeredis.stack import JSONCommandsMixin
 from .commands_mixins.list_mixin import ListCommandsMixin
 from .commands_mixins.pubsub_mixin import PubSubCommandsMixin
 from .commands_mixins.scripting_mixin import ScriptingCommandsMixin
@@ -29,8 +28,8 @@ class FakeSocket(
     SetCommandsMixin,
     BitmapCommandsMixin,
     SortedSetCommandsMixin,
+    JSONCommandsMixin,
 ):
-    _connection_error_class = redis.ConnectionError
 
     def __init__(self, server):
         super(FakeSocket, self).__init__(server)
